package com.example.lfrmobileapp;

import android.content.Context;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.widget.Toast;

import com.google.android.material.bottomnavigation.BottomNavigationView;

import androidx.appcompat.app.AppCompatActivity;
import androidx.navigation.NavController;
import androidx.navigation.Navigation;
import androidx.navigation.ui.AppBarConfiguration;
import androidx.navigation.ui.NavigationUI;

import com.example.lfrmobileapp.databinding.ActivityMainBinding;

import java.io.DataOutputStream;
import java.io.IOException;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

public class MainActivity extends AppCompatActivity {

    private ActivityMainBinding binding;
    private ExtendedSocket socket;
    private DataTransferAsyncTask dataTransferAsyncTask;
    Boolean connected = false;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        binding = ActivityMainBinding.inflate(getLayoutInflater());
        setContentView(binding.getRoot());

        BottomNavigationView navView = findViewById(R.id.nav_view);
        // Passing each menu ID as a set of Ids because each
        // menu should be considered as top level destinations.
        AppBarConfiguration appBarConfiguration = new AppBarConfiguration.Builder(
                R.id.navigation_home, R.id.navigation_dashboard, R.id.navigation_notifications)
                .build();
        NavController navController = Navigation.findNavController(this, R.id.nav_host_fragment_activity_main);
        NavigationUI.setupActionBarWithNavController(this, navController, appBarConfiguration);
        NavigationUI.setupWithNavController(binding.navView, navController);
    }

    public boolean connectToWifi(String ipAddress, int port){
        ExecutorService executor = Executors.newSingleThreadExecutor();
        Future<Boolean> future = executor.submit(() -> {
            Socket tempSocket = new Socket();
            tempSocket.connect(new InetSocketAddress(ipAddress, port), 1000);
            try {
                socket = new ExtendedSocket(tempSocket);
                socket.sendMessage("Verbindung aufbauen");
            } catch (Exception e) {
                socket.closeSocket();
                return false;
            }
            return true;
        });

        try {
            connected = future.get();
        } catch (InterruptedException e) {
            System.err.println("InterruptedException: " + e.getMessage());
        } catch (ExecutionException e) {
            System.err.println("ExecutionException: " + e.getCause().getMessage());
        }

        executor.shutdown();

        if(connected){
            dataTransferAsyncTask = new DataTransferAsyncTask(socket);
            dataTransferAsyncTask.execute();
            return true;
        }else{
            return false;
        }
    }

    public void sendTelegram(String telegram)
    {
        this.dataTransferAsyncTask.writeTelegram(telegram);
    }
}

